/*
  Arduino Uno ADC v1, A5 => 8bits on PORTD pins, ~59kSa/s.
  Processing delay ~21us.
  Stay in 0...5V range on pin A5!
  Formula for PicoScope MSO math channel DAC:

  LowPass((128*D7+64*D6+32*D5+16*D4+8*D3+4*D2+2*D1+1*D0)/256/0.996,15000)*4.8

  By HrHunt @ PicoTech forum
  E-mail: info@lab.fyi
  Thread: https://www.picotech.com/support/topic27831.html
  
  Advanced Arduino ADC from: http://www.microsmart.co.za/technical/2014/03/01/advanced-arduino-adc/
*/

// Define various ADC prescaler
const unsigned char PS_16 = (1 << ADPS2); // ~59kSa/s
const unsigned char PS_32 = (1 << ADPS2) | (1 << ADPS0); 
const unsigned char PS_64 = (1 << ADPS2) | (1 << ADPS1);
const unsigned char PS_128 = (1 << ADPS2) | (1 << ADPS1) | (1 << ADPS0); // ~9kSa/s

void setup()
{
  pinMode(0, OUTPUT);
  pinMode(1, OUTPUT);
  pinMode(2, OUTPUT);
  pinMode(3, OUTPUT);
  pinMode(4, OUTPUT);
  pinMode(5, OUTPUT);
  pinMode(6, OUTPUT);
  pinMode(7, OUTPUT);

  pinMode(A5, INPUT); // Stay in 0...5V range!

  // Set up the ADC
  ADCSRA &= ~PS_128; // Remove bits set by Arduino library

  // You can choose a prescaler from above.
  // PS_16, PS_32, PS_64 or PS_128
  ADCSRA |= PS_16; // Set our own prescaler to 16 (~59kSa/s)

  PORTD = 0x00;
}

void loop()
{
  PORTD = analogRead(A5) / 4;
}
